src/cx/mempool.h

changeset 993
b642eca4b956
parent 985
68754c7de906
--- a/src/cx/mempool.h	Tue Nov 26 22:00:03 2024 +0100
+++ b/src/cx/mempool.h	Tue Nov 26 22:16:27 2024 +0100
@@ -76,11 +76,11 @@
 typedef struct cx_mempool_s CxMempool;
 
 /**
- * Destroys a memory pool and frees the managed memory.
+ * Deallocates a memory pool and frees the managed memory.
  *
  * @param pool the memory pool to destroy
  */
-void cxMempoolDestroy(CxMempool *pool);
+void cxMempoolFree(CxMempool *pool);
 
 /**
  * Creates an array-based memory pool with a shared destructor function.
@@ -93,7 +93,7 @@
  */
 cx_attr_nodiscard
 cx_attr_malloc
-cx_attr_dealloc(cxMempoolDestroy, 1)
+cx_attr_dealloc(cxMempoolFree, 1)
 CxMempool *cxMempoolCreate(size_t capacity, cx_destructor_func destr);
 
 /**
@@ -76,11 +76,11 @@
  *
- * @param pool the memory pool to destroy
+ * @param pool the memory pool to free
  */

mercurial